package com.ruoyi.asset.service;

import java.util.List;

import com.baomidou.mybatisplus.extension.service.IService;
import com.ruoyi.asset.domain.TbFaultReport;

/**
 * 故障报备Service接口
 * 
 * @author 原动力
 * @date 2023-03-27
 */
public interface ITbFaultReportService extends IService<TbFaultReport>
{
    /**
     * 查询故障报备
     * 
     * @param id 故障报备主键
     * @return 故障报备
     */
    public TbFaultReport selectTbFaultReportById(Long id);

    /**
     * 查询故障报备列表
     * 
     * @param tbFaultReport 故障报备
     * @return 故障报备集合
     */
    public List<TbFaultReport> selectTbFaultReportList(TbFaultReport tbFaultReport);

    /**
     * 新增故障报备
     * 
     * @param tbFaultReport 故障报备
     * @return 结果
     */
    public int insertTbFaultReport(TbFaultReport tbFaultReport);

    /**
     * 修改故障报备
     * 
     * @param tbFaultReport 故障报备
     * @return 结果
     */
    public int updateTbFaultReport(TbFaultReport tbFaultReport);

    /**
     * 批量删除故障报备
     * 
     * @param ids 需要删除的故障报备主键集合
     * @return 结果
     */
    public int deleteTbFaultReportByIds(Long[] ids);

    /**
     * 删除故障报备信息
     * 
     * @param id 故障报备主键
     * @return 结果
     */
    public int deleteTbFaultReportById(Long id);
}
